@@ -82,22 +82,40 @@ class ABCRadio:
     def continuous_search(
         self, **params: Unpack[RequestParams]
     ) -> Iterator[SearchResult]:
-        yield self.search(**params)
-        # make first search
-        # yield searchResult
-        # total = x
-        # offset = y
-        # limit = z
-        # while total > offset + limit:
-        # yield search result
-        # offset = search_result.offset
-        # limit
+
+        initial_search = self.search(**params)
+        yield initial_search
+        total = initial_search.total
+        offset = initial_search.offset
+        limit = initial_search.limit
+        while offset + limit < total:
+            offset = offset + limit
+            params["offset"] = offset
+            yield self.search(**params)
 
 
 class RequestParams(TypedDict, total=False):
     """
     **kwarg arguments to be used when searching in the ABC web api
 
+    Parameters
+    ----------
+    from_: datetime
+        The earliest data starts from "2014-04-30T03:00:04+00:00"
+
+    to: datetime
+        to value should be greater than from_
+
+    limit: int
+        number of results to display in a single request, effective limit is 100
+
+    offset: int
+        index at which to start returning results, you can iterate through all
+        radio plays by updating this value. See continuous_search for an example
+        implementation.
+    station: str
+       any one of: "jazz,dig,doublej,unearthed,country,triplej,classic,kidslisten"
+
     """
 
     from_: datetime
@@ -109,7 +127,9 @@ class RequestParams(TypedDict, total=False):
 
 @dataclass
 class RadioSong:
-    """Dataclass for each entity returned from ABCradio.search
+    """
+    Dataclass for each entity returned from ABCradio.search,
+    A RadioSong is a Song played at a specific time on a specific channel.
 
 
     Attributes
@@ -161,6 +181,10 @@ class RadioSong:
 
 @dataclass
 class SearchResult:
+    """
+    Dataclass returned from ABCRadio.search
+    """
+
     total: int
     offset: int
     limit: int
@@ -182,6 +206,10 @@ class SearchResult:
 
 @dataclass
 class Song:
+    """
+    Dataclass to represent a song
+
+    """
 
     title: str
     duration: int
@@ -223,7 +251,7 @@ class Song:
             artists = []
             for artist in json_release["artists"]:
                 artists.append(Artist.from_json(artist))
-        except (KeyError, IndexError):
+        except (KeyError, IndexError, TypeError):
             artists = []
             album = None
 
